package com.winhc.bigdata.bean;

import com.winhc.bigdata.utils.BaseUtils;

/**
 * @Author: XuJiakai
 * 2024/6/5 10:37
 */
public class Tuple3<T0, T1, T2> {

    private static final long serialVersionUID = 1L;

    /**
     * Field 0 of the tuple.
     */
    public T0 f0;
    /**
     * Field 1 of the tuple.
     */
    public T1 f1;
    /**
     * Field 2 of the tuple.
     */
    public T2 f2;

    /**
     * Creates a new tuple where all fields are null.
     */
    public Tuple3() {
    }

    /**
     * Creates a new tuple and assigns the given values to the tuple's fields.
     *
     * @param f0 The value for field 0
     * @param f1 The value for field 1
     * @param f2 The value for field 2
     */
    public Tuple3(T0 f0, T1 f1, T2 f2) {
        this.f0 = f0;
        this.f1 = f1;
        this.f2 = f2;
    }


    @Override
    public String toString() {
        return BaseUtils.toString(this);
    }

    /**
     * Deep equality for tuples by calling equals() on the tuple members.
     *
     * @param o the object checked for equality
     * @return true if this is equal to o.
     */
    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof Tuple3)) {
            return false;
        }
        @SuppressWarnings("rawtypes")
        Tuple3 tuple = (Tuple3) o;
        if (f0 != null ? !f0.equals(tuple.f0) : tuple.f0 != null) {
            return false;
        }
        if (f1 != null ? !f1.equals(tuple.f1) : tuple.f1 != null) {
            return false;
        }
        if (f2 != null ? !f2.equals(tuple.f2) : tuple.f2 != null) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int result = f0 != null ? f0.hashCode() : 0;
        result = 31 * result + (f1 != null ? f1.hashCode() : 0);
        result = 31 * result + (f2 != null ? f2.hashCode() : 0);
        return result;
    }


    /**
     * Creates a new tuple and assigns the given values to the tuple's fields. This is more
     * convenient than using the constructor, because the compiler can infer the generic type
     * arguments implicitly. For example: {@code Tuple3.of(n, x, s)} instead of {@code new
     * Tuple3<Integer, Double, String>(n, x, s)}
     */
    public static <T0, T1, T2> Tuple3<T0, T1, T2> of(T0 f0, T1 f1, T2 f2) {
        return new Tuple3<>(f0, f1, f2);
    }
}
